@@ -20,7 +20,7 @@
     slouken@libsdl.org
 */
 
-/* $Id: SDL_ttf.c,v 1.27 2004/11/17 22:59:44 slouken Exp $ */
+/* $Id: SDL_ttf.c 2304 2006-05-01 09:26:07Z slouken $ */
 
 #include <math.h>
 #include <stdio.h>
@@ -233,6 +233,9 @@ static unsigned long RWread(
 
 	src = (SDL_RWops *)stream->descriptor.pointer;
 	SDL_RWseek( src, (int)offset, SEEK_SET );
+	if ( count == 0 ) {
+		return 0;
+	}
 	return SDL_RWread( src, buffer, 1, (int)count );
 }
 
@@ -307,8 +310,8 @@ TTF_Font* TTF_OpenFontIndexRW( SDL_RWops *src, int freesrc, int ptsize, long ind
 
 	  /* Get the scalable font metrics for this font */
 	  scale = face->size->metrics.y_scale;
-	  font->ascent  = FT_CEIL(FT_MulFix(face->bbox.yMax, scale));
-	  font->descent = FT_CEIL(FT_MulFix(face->bbox.yMin, scale));
+	  font->ascent  = FT_CEIL(FT_MulFix(face->ascender, scale));
+	  font->descent = FT_CEIL(FT_MulFix(face->descender, scale));
 	  font->height  = font->ascent - font->descent + /* baseline */ 1;
 	  font->lineskip = FT_CEIL(FT_MulFix(face->height, scale));
 	  font->underline_offset = FT_FLOOR(FT_MulFix(face->underline_position, scale));
@@ -1575,6 +1578,7 @@ SDL_Surface *TTF_RenderUNICODE_Blended(TTF_Font *font,
 	xstart = 0;
 	swapped = TTF_byteswapped;
 	pixel = (fg.r<<16)|(fg.g<<8)|fg.b;
+	SDL_FillRect(textbuf, NULL, pixel);	/* Initialize with fg and 0 alpha */
 
 	for ( ch=text; *ch; ++ch ) {
 		Uint16 c = *ch;
@@ -1694,6 +1698,8 @@ SDL_Surface *TTF_RenderGlyph_Blended(TTF_Font *font, Uint16 ch, SDL_Color fg)
 
 	/* Copy the character from the pixmap */
 	pixel = (fg.r<<16)|(fg.g<<8)|fg.b;
+	SDL_FillRect(textbuf, NULL, pixel);	/* Initialize with fg and 0 alpha */
+
 	for ( row=0; row<textbuf->h; ++row ) {
 		/* Changed src to take pitch into account, not just width */
 		src = glyph->pixmap.buffer + row * glyph->pixmap.pitch;
